@@ -27,13 +27,12 @@
 #include "settingswidget.h"
 
 #include <KConfigDialog> // IDW test.
-
+#include <QDebug>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KFileDialog>
-#include <KTemporaryFile>
+#include <QFileDialog>
+#include <QTemporaryFile>
 #include <kio/netaccess.h>
-#include <QTimer>
 
 #include "prefs.h"
 
@@ -66,9 +65,9 @@ Game::Game (const int d, KCubeBoxWidget * view, QWidget * parent)
    m_ai                 = new AI_Main (this, m_side);
    m_steps              = new QList<int>;
 
-   connect (m_view, SIGNAL(mouseClick(int,int)), SLOT(startHumanMove(int,int)));
-   connect (m_ai,   SIGNAL(done(int)), SLOT(moveCalculationDone(int)));
-   connect (m_view, SIGNAL(animationDone(int)), SLOT(animationDone(int)));
+   connect(m_view, &KCubeBoxWidget::mouseClick, this, &Game::startHumanMove);
+   connect(m_ai, &AI_Main::done, this, &Game::moveCalculationDone);
+   connect(m_view, &KCubeBoxWidget::animationDone, this, &Game::animationDone);
 }
 
 Game::~Game()
@@ -134,7 +133,7 @@ void Game::showSettingsDialog (bool show)
       settings->setFaceType (KPageDialog::Plain);
       SettingsWidget * widget = new SettingsWidget (m_parent);
       settings->addPage (widget, i18n("General"), "games-config-options");
-      connect (settings, SIGNAL(settingsChanged(QString)), SLOT(newSettings()));
+      connect(settings, &KConfigDialog::settingsChanged, this, &Game::newSettings);
       m_settingsPage = widget;		// Used when reverting/editing settings.
    }
    if (! show) return;
@@ -293,8 +292,7 @@ void Game::computeMove()
    setStopAction();
    emit setAction (HINT, false);
    if (isComputer (m_currentPlayer)) {
-       emit statusMessage (i18n("Computer player %1 is moving")
-                           .arg(m_currentPlayer), false);
+       emit statusMessage (i18n("Computer player %1 is moving", m_currentPlayer), false);
    }
    m_ai->getMove (m_currentPlayer, m_box);
 }
@@ -564,10 +562,10 @@ void Game::saveGame (bool saveAs)
 {
    if (saveAs || m_gameURL.isEmpty()) {
       int result=0;
-      KUrl url;
+      QUrl url;
 
       do {
-         url = KFileDialog::getSaveUrl (m_gameURL.url(), "*.kjc", m_view, 0);
+         url = QFileDialog::getSaveFileUrl (m_view, QString(), m_gameURL.url(), "*.kjc");
 
          if (url.isEmpty())
             return;
@@ -575,7 +573,8 @@ void Game::saveGame (bool saveAs)
          // check filename
          QRegExp pattern ("*.kjc", Qt::CaseSensitive, QRegExp::Wildcard);
          if (! pattern.exactMatch (url.fileName())) {
-            url.setFileName (url.fileName()+".kjc");
+            url = url.adjusted(QUrl::RemoveFilename);
+            url.setPath(url.path() + url.fileName()+".kjc");
          }
 
          if (KIO::NetAccess::exists (url, KIO::NetAccess::DestinationSide,
@@ -592,7 +591,7 @@ void Game::saveGame (bool saveAs)
       m_gameURL = url;
    }
 
-   KTemporaryFile tempFile;
+   QTemporaryFile tempFile;
    tempFile.open();
    KConfig config (tempFile.fileName(), KConfig::SimpleConfig);
    KConfigGroup main (&config, "KJumpingCube");
@@ -613,10 +612,10 @@ void Game::saveGame (bool saveAs)
 void Game::loadGame()
 {
    bool fileOk=true;
-   KUrl url;
+   QUrl url;
 
    do {
-      url = KFileDialog::getOpenUrl (m_gameURL.url(), "*.kjc", m_view, 0);
+      url = QFileDialog::getOpenFileUrl (m_view, QString(), m_gameURL.url(), "*.kjc");
       if (url.isEmpty())
          return;
       if (! KIO::NetAccess::exists(url, KIO::NetAccess::SourceSide, m_view)) {
@@ -699,7 +698,7 @@ bool Game::newGameOK()
       if (m_settingsPage) {
           m_settingsPage->kcfg_CubeDim->setValue (m_side);
       }
-      Prefs::self()->writeConfig();
+      Prefs::self()->save();
    }
    qDebug() << "CONTINUE GAME";
    return false;			// Continue the current game.
@@ -830,8 +829,8 @@ void Game::readProperties (const KConfigGroup& config)
   int cubeDim = config.readEntry ("CubeDim", minSide);
   if ((cubeDim < minSide) || (cubeDim > maxSide)) {
      KMessageBox::sorry (m_view, i18n("The file's cube box size is outside "
-                                    "the range %1 to %2. It will be set to %1.")
-                                    .arg(minSide).arg(maxSide));
+                                    "the range %1 to %2. It will be set to %1.",
+                                    minSide, maxSide));
      cubeDim = 3;
   }
 
@@ -845,8 +844,7 @@ void Game::readProperties (const KConfigGroup& config)
 	list = config.readEntry (key, QStringList());
 	// List length must be 2, owner must be 0-2, value >= 1 and <= max().
 	if (list.count() < 2) {
-	    KMessageBox::sorry (m_view, i18n("Missing input line for cube %1.")
-		    .arg(key));
+	    KMessageBox::sorry (m_view, i18n("Missing input line for cube %1.", key));
 	    owner = 0;
 	    value = 1;
 	}
@@ -856,15 +854,14 @@ void Game::readProperties (const KConfigGroup& config)
 	}
 	if ((owner < 0) || (owner > 2)) {
 	    KMessageBox::sorry (m_view, i18n("Owner of cube %1 is outside the "
-                                           "range 0 to 2.").arg(key));
+                                           "range 0 to 2.", key));
 	    owner = 0;
 	}
 	int index = x * m_side + y;
 	maxValue = (owner == 0) ? 1 : m_box->maxValue (index);
 	if ((value < 1) || (value > maxValue)) {
 	    KMessageBox::sorry (m_view, i18n("Value of cube %1 is outside the "
-                                           "range 1 to %2.")
-                                           .arg(key).arg(maxValue));
+                                           "range 1 to %2.", key, maxValue));
 	    value = maxValue;
 	}
 	m_view->displayCube (index, (Player) owner, value);
@@ -886,7 +883,7 @@ void Game::readProperties (const KConfigGroup& config)
 
    // Restore the game and player settings.
    loadSavedSettings (config);
-   Prefs::self()->writeConfig();
+   Prefs::self()->save();
    setUpNextTurn();
 }
 
@@ -966,4 +963,4 @@ void Game::animationDone (int index)
    }
 }
 
-#include "game.moc"
+
